@@ -1,9 +1,9 @@
-context("orcid_doi")
-
 test_that("orcid_doi basic functionality works", {
   skip_on_cran()
   
-  aa <- orcid_doi("10.1087/20120404")
+  vcr::use_cassette("orcid_doi", {
+    aa <- orcid_doi("10.1087/20120404")
+  })
   
   expect_is(aa, "orcid_doi")
   expect_is(unclass(aa), "list")
@@ -16,7 +16,9 @@ test_that("orcid_doi accepts many doi's", {
   skip_on_cran()
   
   dois <- c("10.1371/journal.pone.0025995","10.1371/journal.pone.0053712")
-  bb <- orcid_doi(dois)
+  vcr::use_cassette("orcid_doi_many_dois", {
+    bb <- orcid_doi(dois)
+  })
   
   expect_is(bb, "orcid_doi")
   expect_is(unclass(bb), "list")
@@ -28,8 +30,10 @@ test_that("orcid_doi accepts many doi's", {
 test_that("orcid_doi paging parameters works as expected", {
   skip_on_cran()
   
-  pg1 <- orcid_doi("10.1087/20120404", rows = 3)
-  pg2 <- orcid_doi("10.1087/20120404", rows = 3, start = 4)
+  vcr::use_cassette("orcid_doi_pagination", {
+    pg1 <- orcid_doi("10.1087/20120404", rows = 3)
+    pg2 <- orcid_doi("10.1087/20120404", rows = 3, start = 4)
+  })
   
   expect_false(identical(pg1[[1]], pg2[[1]]))
   expect_type(attr(pg1[[1]], "found"), "integer")
